.. only: not latex
    .. image:: carma_logo.png

CARMA - Armadillo converters
============================
*CARMA is a header only library providing conversions between Numpy arrays and Armadillo matrices.*

.. only: not latex

    Contents:

.. toctree::
    :maxdepth: 2

    introduction

.. toctree::
    :caption: The basics
    :maxdepth: 2

    basic_usage
    examples

.. toctree::
    :caption: Memory Management
    :maxdepth: 2

    memory_management

.. toctree::
    :caption: Advanced
    :maxdepth: 1

    configuration
    building

.. toctree::
    :caption: CARMA
    :maxdepth: 2

    carma
